*******************************************************
* This file uses individual_1990.dta and creates a    *
* couple-level data file for 1990.                    *
*******************************************************


clear
macro drop _all
program drop _all
set more off
set linesize 80

capture log close
log using "couple_1990.log",replace

set mem 900m



use "individual_1990.dta"



*******************************
* RESHAPE TO MAKE COUPLE DATA *
*******************************


reshape wide educ re age educ_l agec geog_mob perwt qmarst sex, i(serial) j(R)


*
* recode so that in opposite sex couples all of the "1" variables correspond to the
* husband and all of the "0" variables correspond to the wife
*


foreach x in educ re age educ_l agec geog_mob perwt qmarst {
 quietly gen     `x'_f = `x'1 if sex1 == 2 & (rel_var == 1 | rel_var == 2) /*female*/
 quietly replace `x'_f = `x'0 if sex0 == 2 & (rel_var == 1 | rel_var == 2) /*female*/
 quietly gen     `x'_m = `x'1 if sex1 == 1 & (rel_var == 1 | rel_var == 2) /*male*/
 quietly replace `x'_m = `x'0 if sex0 == 1 & (rel_var == 1 | rel_var == 2) /*male*/

 quietly replace `x'1 = `x'_m if (rel_var == 1 | rel_var == 2)
 quietly replace `x'0 = `x'_f if (rel_var == 1 | rel_var == 2)

}

drop *_f *_m



bysort rel_var: tab qmarst1 sex1
bysort rel_var: tab qmarst0 sex0




********
* SAVE *
********


saveold "couple_1990.dta", replace



log close




